/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvFt@CYt߂̍쐬

	Copyright 2013-2021 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <stdio.h>

using namespace PdfTk;

void addAnnotFileAttachment(PtlPage& page, const PtlParamString& attachmentfilename);

int main(int argc, char* argv[])
{
	if (argc < 4) {
		printf("usage: AppendAnnotFileAttachment.exe in-pdf-file out-pdf-file attachment-file\n");
		return 1;
	}
	try
	{
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);
		PtlParamString attachmentfilename(argv[3]);

		PtlPDFDocument doc;

		// PDFt@C[h܂B
		doc.load(input);

		// y[WRei̎擾
		PtlPages& pages = doc.getPages();

		// y[WRei󂩂ǂ
		if (pages.isEmpty()){
			printf("y[WRei\n");
			return 1;
		}

		// y[W̎擾
		PtlPage page = pages.get(0);

		// ߂̐ݒ
		addAnnotFileAttachment(page, attachmentfilename);
		
		// t@Cɕۑ܂B
		doc.save(output);

		printf("!\n");
	}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return 1;
	}	
	return 0;
}

void addAnnotFileAttachment(PtlPage& page, const PtlParamString& attachmentfilename)
{
	// ߃Rei̎擾
	PtlAnnots& annots = page.getAnnots();

	// PDF̃t@CYt
	PtlAnnotFileAttachment annotfileattachment;

	// ACR^Cvݒ ICON_PUSHPIN = 3, /* vbVs */
	annotfileattachment.setIconType(PtlAnnotFileAttachment::ICON_PUSHPIN);

	// ACRTCY
	PtlRect rectSize = annotfileattachment.getRect();

	// `Wݒ W̒PʂmmŌ_(0,0)͍
	annotfileattachment.setRect(PtlRect(50.0f, 50.0f, 50.0f+rectSize.getRight(), 50.0f+rectSize.getTop()));

	// eݒiߗpɕ\eLXgEǂȌ`ł̒߃Rec̑֐j
	annotfileattachment.setTextContents("ǂȌ`ł̒߃Rec̑֐");

	// ̐ݒ(2000/5/5 12:00:00)
	annotfileattachment.setDate(PtlDate(2000, 5, 5, 12, 0, 0));

	// Fݒ
	annotfileattachment.setColor(PtlColorDeviceRGB(1.0f, 0.0f, 1.0f));

	// EX^Cݒ BORDER_SOLID = 1, /* (߂͂ގ̋`) */
	annotfileattachment.setBorderStyle(PtlAnnotText::BORDER_SOLID);

	// E擾 BORDER_WIDTH_THICK = 3 /*  */
	annotfileattachment.setBorderWidth(PtlAnnotText::BORDER_WIDTH_THICK);

	// |bvAbvEBhẼ^Cgݒ
	annotfileattachment.setMarkUpTitle("|bvAbvEBhẼ^Cg");

	// TuWFNg̒Zݒ
	annotfileattachment.setMarkUpSubj("TuWFNg̒Zݒ");

	// ߐ̐ݒ
	annotfileattachment.setMarkUpDate(PtlDate(2000, 4 , 1, 23, 59, 59));

	// sxݒ 0.0 ` 1.0B0.0A1.0s
	annotfileattachment.setMarkUpCA(1.0f);

	// Ytt@Cݒ
	annotfileattachment.setFileName(attachmentfilename);

	// Ytt@C̓ǂݍ
	PtlParamInput inpitAttach(attachmentfilename);
	annotfileattachment.readFile(inpitAttach);

	//------
	PtlAnnotPopup annotpopup;

	// `Wݒ W̒PʂmmŌ_(0,0)͍
	annotpopup.setRect(PtlRect(100.0f, 100.0f, 150.0f, 150.0f)); 

	// I[vԂݒ true=I[v
	annotpopup.setOpenState(true);

	// |bvAbv߂ݒ
	annotfileattachment.setAnnotPopUp(annotpopup);

	//------

	// ߂̒ǉ
	annots.append(annotfileattachment);
}
