/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvFX^v߂̍쐬

	Copyright 2013-2021 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <math.h>
#include <stdio.h>

using namespace PdfTk;

void addPreDefinedStampAnnot(PtlAnnots& annots);
void addPreDefinedStampAnnot2(PtlAnnots& annots);
void addCustomStampAnnotFromPdf(PtlAnnots& annots, const char* pathPdf);
void addCustomStampAnnotFromImage(PtlAnnots& annots, const char* pathImage);
void addCustomStampAnnotFromDrawContent(PtlAnnots& annots);
void drawDateStamp(PtlContent& content, float sizeStamp, const char* szDate, const char* szName);

int main(int argc, char* argv[])
{
	if (argc < 4) {
		printf("usage: AppendAnnotStamp.exe in-pdf-file out-pdf-file X^v [in-xxx-file]\n\n");
		printf("X^v\n0 : W  1 : W2  2 : JX^(PDF)  3 : JX^(Image)  4 : JX^(t)\n");
		return 1;
	}

	try
	{
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);

		const char* stampKind = argv[3];
		switch (stampKind[0]) {
		case '0':
		case '1':
		case '2':
		case '3':
		case '4':
			break;
		default:
			printf("usage: AppendAnnotStamp.exe in-pdf-file out-pdf-file X^v [in-xxx-file]\n\n");
			printf("X^v\n0 : W  1 : W2  2 : JX^(PDF)  3 : JX^(Image)  4 : JX^(t)\n");
			return 1;
		}

		PtlPDFDocument doc;

		// PDFt@C[h܂B
		doc.load(input);

		// y[WRei̎擾
		PtlPages& pages = doc.getPages();

		// y[WRei󂩂ǂ
		if (pages.isEmpty()){
			printf("y[WRei\n");
			return 1;
		}

		// Py[Wڂ̎擾
		PtlPage page = pages.get(0);
		
		// ߃Rei̎擾
		PtlAnnots& annots = page.getAnnots();

		switch (stampKind[0]) {
		case '0':
			// W
			addPreDefinedStampAnnot(annots);
			break;
		case '1':
			// W2
			addPreDefinedStampAnnot2(annots);
			break;
		case '2':
			// ǂݍPDFOςƂX^v
			if (argc < 5) {
				printf("usage: java AppendAnnotStamp in-pdf-file out-pdf-file X^v in-pdf-file");
				return 1;
			}
			addCustomStampAnnotFromPdf(annots, argv[4]);
			break;
		case '3':
			// ǂݍ񂾉摜OςƂX^v
			if (argc < 5) {
				printf("usage: java AppendAnnotStamp in-pdf-file out-pdf-file X^v in-image-file");
				return 1;
			}
			addCustomStampAnnotFromImage(annots, argv[4]);
			break;
		case '4':
			// tOςƂĕ`
			addCustomStampAnnotFromDrawContent(annots);
			break;
		}

		// t@Cɕۑ܂B
		doc.save(output);

		printf("!\n");
	}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return 1;
	}
	return 0;
}

void addPreDefinedStampAnnot(PtlAnnots& annots)
{
	PtlAnnotStamp stampAnnot1;
	stampAnnot1.setIconType(PtlAnnotStamp::ICON_APPROVED);
	PtlRect rectSize1 = stampAnnot1.getRect();
	stampAnnot1.setRect(PtlRect(10.0f, 270.0f, 10.0f+rectSize1.getRight(), 270.0f+rectSize1.getTop()));
	stampAnnot1.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot1);

	PtlAnnotStamp stampAnnot2;
	stampAnnot2.setIconType(PtlAnnotStamp::ICON_AS_IS);
	PtlRect rectSize2 = stampAnnot2.getRect();
	stampAnnot2.setRect(PtlRect(10.0f, 250.0f, 10.0f+rectSize2.getRight(), 250.0f+rectSize2.getTop()));
	stampAnnot2.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot2);

	PtlAnnotStamp stampAnnot3;
	stampAnnot3.setIconType(PtlAnnotStamp::ICON_CONFIDENTIAL);
	PtlRect rectSize3 = stampAnnot3.getRect();
	stampAnnot3.setRect(PtlRect(10.0f, 230.0f, 10.0f+rectSize3.getRight(), 230.0f+rectSize3.getTop()));
	stampAnnot3.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot3);

	PtlAnnotStamp stampAnnot4;
	stampAnnot4.setIconType(PtlAnnotStamp::ICON_DEPARTMENTAL);
	PtlRect rectSize4 = stampAnnot4.getRect();
	stampAnnot4.setRect(PtlRect(10.0f, 210.0f, 10.0f+rectSize4.getRight(), 210.0f+rectSize4.getTop()));
	stampAnnot4.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot4);

	PtlAnnotStamp stampAnnot5;
	stampAnnot5.setIconType(PtlAnnotStamp::ICON_DRAFT);
	PtlRect rectSize5 = stampAnnot5.getRect();
	stampAnnot5.setRect(PtlRect(10.0f, 190.0f, 10.0f+rectSize5.getRight(), 190.0f+rectSize5.getTop()));
	stampAnnot5.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot5);

	PtlAnnotStamp stampAnnot6;
	stampAnnot6.setIconType(PtlAnnotStamp::ICON_EXPERIMENTAL);
	PtlRect rectSize6 = stampAnnot6.getRect();
	stampAnnot6.setRect(PtlRect(10.0f, 170.0f, 10.0f+rectSize6.getRight(), 170.0f+rectSize6.getTop()));
	stampAnnot6.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot6);

	PtlAnnotStamp stampAnnot7;
	stampAnnot7.setIconType(PtlAnnotStamp::ICON_EXPIRED);
	PtlRect rectSize7 = stampAnnot7.getRect();
	stampAnnot7.setRect(PtlRect(10.0f, 150.0f, 10.0f+rectSize7.getRight(), 150.0f+rectSize7.getTop()));
	stampAnnot7.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot7);

	PtlAnnotStamp stampAnnot8;
	stampAnnot8.setIconType(PtlAnnotStamp::ICON_FINAL);
	PtlRect rectSize8 = stampAnnot8.getRect();
	stampAnnot8.setRect(PtlRect(10.0f, 130.0f, 10.0f+rectSize8.getRight(), 130.0f+rectSize8.getTop()));
	stampAnnot8.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot8);

	PtlAnnotStamp stampAnnot9;
	stampAnnot9.setIconType(PtlAnnotStamp::ICON_FOR_COMMENT);
	PtlRect rectSize9 = stampAnnot9.getRect();
	stampAnnot9.setRect(PtlRect(10.0f, 110.0f, 10.0f+rectSize9.getRight(), 110.0f+rectSize9.getTop()));
	stampAnnot9.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot9);

	PtlAnnotStamp stampAnnot10;
	stampAnnot10.setIconType(PtlAnnotStamp::ICON_FOR_PUBLIC_RELEASE);
	PtlRect rectSize10 = stampAnnot10.getRect();
	stampAnnot10.setRect(PtlRect(10.0f, 90.0f, 10.0f+rectSize10.getRight(), 90.0f+rectSize10.getTop()));
	stampAnnot10.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot10);

	PtlAnnotStamp stampAnnot11;
	stampAnnot11.setIconType(PtlAnnotStamp::ICON_NOT_APPROVED);
	PtlRect rectSize11 = stampAnnot11.getRect();
	stampAnnot11.setRect(PtlRect(10.0f, 70.0f, 10.0f+rectSize11.getRight(), 70.0f+rectSize11.getTop()));
	stampAnnot11.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot11);

	PtlAnnotStamp stampAnnot12;
	stampAnnot12.setIconType(PtlAnnotStamp::ICON_NOT_FOR_PUBLIC_RELEASE);
	PtlRect rectSize12 = stampAnnot12.getRect();
	stampAnnot12.setRect(PtlRect(10.0f, 50.0f, 10.0f+rectSize12.getRight(), 50.0f+rectSize12.getTop()));
	stampAnnot12.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot12);

	PtlAnnotStamp stampAnnot13;
	stampAnnot13.setIconType(PtlAnnotStamp::ICON_SOLD);
	PtlRect rectSize13 = stampAnnot13.getRect();
	stampAnnot13.setRect(PtlRect(10.0f, 30.0f, 10.0f+rectSize13.getRight(), 30.0f+rectSize13.getTop()));
	stampAnnot13.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot13);

	PtlAnnotStamp stampAnnot14;
	stampAnnot14.setIconType(PtlAnnotStamp::ICON_TOP_SECRET);
	PtlRect rectSize14 = stampAnnot14.getRect();
	stampAnnot14.setRect(PtlRect(10.0f, 10.0f, 10.0f+rectSize14.getRight(), 10.0f+rectSize14.getTop()));
	stampAnnot14.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot14);
}

void addPreDefinedStampAnnot2(PtlAnnots& annots)
{
	PtlAnnotStamp stampAnnot1;
	stampAnnot1.setIconType(PtlAnnotStamp::ICON_SB_APPROVED);
	PtlRect rectSize1 = stampAnnot1.getRect();
	stampAnnot1.setRect(PtlRect(10.0f, 270.0f, 10.0f+rectSize1.getRight(), 270.0f+rectSize1.getTop()));
	stampAnnot1.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot1);

	PtlAnnotStamp stampAnnot2;
	stampAnnot2.setIconType(PtlAnnotStamp::ICON_SB_COMPLETED);
	PtlRect rectSize2 = stampAnnot2.getRect();
	stampAnnot2.setRect(PtlRect(10.0f, 250.0f, 10.0f+rectSize2.getRight(), 250.0f+rectSize2.getTop()));
	stampAnnot2.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot2);

	PtlAnnotStamp stampAnnot3;
	stampAnnot3.setIconType(PtlAnnotStamp::ICON_SB_CONFIDENTIAL);
	PtlRect rectSize3 = stampAnnot3.getRect();
	stampAnnot3.setRect(PtlRect(10.0f, 230.0f, 10.0f+rectSize3.getRight(), 230.0f+rectSize3.getTop()));
	stampAnnot3.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot3);

	PtlAnnotStamp stampAnnot4;
	stampAnnot4.setIconType(PtlAnnotStamp::ICON_SB_DRAFT);
	PtlRect rectSize4 = stampAnnot4.getRect();
	stampAnnot4.setRect(PtlRect(10.0f, 210.0f, 10.0f+rectSize4.getRight(), 210.0f+rectSize4.getTop()));
	stampAnnot4.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot4);

	PtlAnnotStamp stampAnnot5;
	stampAnnot5.setIconType(PtlAnnotStamp::ICON_SB_FINAL);
	PtlRect rectSize5 = stampAnnot5.getRect();
	stampAnnot5.setRect(PtlRect(10.0f, 190.0f, 10.0f+rectSize5.getRight(), 190.0f+rectSize5.getTop()));
	stampAnnot5.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot5);

	PtlAnnotStamp stampAnnot6;
	stampAnnot6.setIconType(PtlAnnotStamp::ICON_SB_FOR_COMMENT);
	PtlRect rectSize6 = stampAnnot6.getRect();
	stampAnnot6.setRect(PtlRect(10.0f, 170.0f, 10.0f+rectSize6.getRight(), 170.0f+rectSize6.getTop()));
	stampAnnot6.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot6);

	PtlAnnotStamp stampAnnot7;
	stampAnnot7.setIconType(PtlAnnotStamp::ICON_SB_FOR_PUBLIC_RELEASE);
	PtlRect rectSize7 = stampAnnot7.getRect();
	stampAnnot7.setRect(PtlRect(10.0f, 150.0f, 10.0f+rectSize7.getRight(), 150.0f+rectSize7.getTop()));
	stampAnnot7.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot7);

	PtlAnnotStamp stampAnnot8;
	stampAnnot8.setIconType(PtlAnnotStamp::ICON_SB_INFORMATIONONLY);
	PtlRect rectSize8 = stampAnnot8.getRect();
	stampAnnot8.setRect(PtlRect(10.0f, 130.0f, 10.0f+rectSize8.getRight(), 130.0f+rectSize8.getTop()));
	stampAnnot8.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot8);

	PtlAnnotStamp stampAnnot9;
	stampAnnot9.setIconType(PtlAnnotStamp::ICON_SB_NOT_APPROVED);
	PtlRect rectSize9 = stampAnnot9.getRect();
	stampAnnot9.setRect(PtlRect(10.0f, 110.0f, 10.0f+rectSize9.getRight(), 110.0f+rectSize9.getTop()));
	stampAnnot9.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot9);

	PtlAnnotStamp stampAnnot10;
	stampAnnot10.setIconType(PtlAnnotStamp::ICON_SB_NOT_FOR_PUBLIC_RELEASE);
	PtlRect rectSize10 = stampAnnot10.getRect();
	stampAnnot10.setRect(PtlRect(10.0f, 90.0f, 10.0f+rectSize10.getRight(), 90.0f+rectSize10.getTop()));
	stampAnnot10.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot10);

	PtlAnnotStamp stampAnnot11;
	stampAnnot11.setIconType(PtlAnnotStamp::ICON_SB_PRELIMINARYRESULTS);
	PtlRect rectSize11 = stampAnnot11.getRect();
	stampAnnot11.setRect(PtlRect(10.0f, 70.0f, 10.0f+rectSize11.getRight(), 70.0f+rectSize11.getTop()));
	stampAnnot11.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot11);

	PtlAnnotStamp stampAnnot12;
	stampAnnot12.setIconType(PtlAnnotStamp::ICON_SB_VOID);
	PtlRect rectSize12 = stampAnnot12.getRect();
	stampAnnot12.setRect(PtlRect(10.0f, 50.0f, 10.0f+rectSize12.getRight(), 50.0f+rectSize12.getTop()));
	stampAnnot12.setAnnotFlags(PtlAnnot::FLAG_PRINT);
	annots.append(stampAnnot12);
}

void addCustomStampAnnotFromPdf(PtlAnnots& annots, const char* pathPdf)
{
	PtlAnnotStamp stampAnnot;
	
	PtlPDFDocument doc_custom;
	// PDFt@C
	PtlParamInput inputCustom(pathPdf);
	// X^vɂPDFt@C[h܂B
	doc_custom.load(inputCustom);

    PtlPages& pagesCustomStamp = doc_custom.getPages();
	// y[WRei󂩂ǂ
    if (pagesCustomStamp.isEmpty())
    {
		printf("y[WRei\n");
        return;
    }

	// ǉꂽ摜y[W擾
	PtlPage pageCustomStamp = pagesCustomStamp.get(0);
	// 摜y[W𒍎߂ɒǉ
	stampAnnot.setPage(pageCustomStamp);

	PtlSize size = pageCustomStamp.getSize();

	stampAnnot.setRect(PtlRect(10.0f, 100.0f, 10.0f+size.getWidth(), 100.0f+size.getHeight()));
	stampAnnot.setIconType(PtlAnnotStamp::ICON_CUSTOM);
	stampAnnot.setAnnotFlags(PtlAnnot::FLAG_PRINT);

	stampAnnot.setIconName("MyIcon");

	annots.append(stampAnnot);
}

void addCustomStampAnnotFromImage(PtlAnnots& annots, const char* pathImage)
{
	PtlAnnotStamp stampAnnot;

	// 摜`p[^
	PtlParamDrawImage paramDrawImage;
	// 摜t@C
	PtlParamInput inputCustom(pathImage);
	// 摜`p[^ɉ摜t@Cݒ
	paramDrawImage.setImageStream(inputCustom);
	
	// 摜y[Wp[^
	PtlParamImagePage paramImagePage;
	// 摜y[Wp[^ɉ摜`p[^ݒ
	paramImagePage.setImage(paramDrawImage);
	// 摜y[W̃TCY摜TCYɂ킹
	paramImagePage.setPaperType(PtlParamImagePage::PAPER_IMAGE_SIZE);

	// 摜y[Wp[^쐬y[W
	PtlPage pageCustomStamp(paramImagePage);

	// 摜y[W𒍎߂ɒǉ
	stampAnnot.setPage(pageCustomStamp);

	PtlSize size = pageCustomStamp.getSize();

	stampAnnot.setRect(PtlRect(10.0f, 100.0f, 10.0f+size.getWidth(), 100.0f+size.getHeight()));
	stampAnnot.setIconType(PtlAnnotStamp::ICON_CUSTOM);
	stampAnnot.setAnnotFlags(PtlAnnot::FLAG_PRINT);

	stampAnnot.setIconName("MyIcon");

	annots.append(stampAnnot);
}

void addCustomStampAnnotFromDrawContent(PtlAnnots& annots)
{
	// X^vTCY
	float sizeStamp = 30.0f;

	PtlAnnotStamp stampAnnot;

	stampAnnot.setRect(PtlRect(10.0f, 100.0f, 10.0f + sizeStamp, 100.0f + sizeStamp));
	stampAnnot.setIconType(PtlAnnotStamp::ICON_CUSTOM);
	stampAnnot.setAnnotFlags(PtlAnnot::FLAG_PRINT);

	// t`悷鉼̃y[W
	PtlPage pageCustomStamp;
	pageCustomStamp.setMediaBox(PtlRect(0, 0, sizeStamp, sizeStamp));

	// t`悷Reg
	PtlContent& content = pageCustomStamp.getContent();

	// Regɓt`
	//drawDateStamp(content, sizeStamp, "2014/09/8", "");
	drawDateStamp(content, sizeStamp, "2014/09/8", "Suzuki");

	// 摜y[W𒍎߂ɒǉ
	stampAnnot.setPage(pageCustomStamp);

	stampAnnot.setIconName("MyIcon");

	annots.append(stampAnnot);
}

void drawDateStamp(PtlContent& content, float sizeStamp, const char* szDate, const char* szName)
{
	// X^vɊOڂ`
	PtlRect rectStamp(0, 0, sizeStamp, sizeStamp);

	// X^v̐F
	PtlColorDeviceRGB color = PtlColorDeviceRGB(1.0f, 0.0f, 0.0f);

	// X^v̉~/`悷p[^[
	PtlParamDrawShape paramDrawShape;
	paramDrawShape.setLineStyle(PtlParamDrawShape::LINE_STYLE_SOLID);
	paramDrawShape.setLineWidth(PtlParamDrawShape::LINE_WIDTH_THIN);
	paramDrawShape.setLineColor(color);
	paramDrawShape.setFillColor(PtlColorNone());

	// X^v̉~`
	content.drawCircle(rectStamp, paramDrawShape);

	#define PI 3.141592
	// ~̒S15xŐƉ~Ƃ
	double rad = 15.0f * PI / 180.0;
	// ~̔a
	float r = sizeStamp / 2;
	// ~̒S_ւx̒
	float xx = r * (float)cos(rad);
	// ~̒S_ւy̒
	float yy = r * (float)sin(rad);
	// [xW
	float from_x = r - xx;
	// [yW
	float to_x = r + xx;
	// [xW
	float upper_y = r + yy;
	// [yW
	float lower_y = r - yy;

	// ~̒ɏ`
	content.drawLine(PtlPoint(from_x,upper_y), PtlPoint(to_x,upper_y), paramDrawShape);
	// ~̒ɉ`
	content.drawLine(PtlPoint(from_x,lower_y), PtlPoint(to_x,lower_y), paramDrawShape);

	// t̃tHg
	float fontSizeDate = sizeStamp / 2.15f;	// yyyy/mm/dd z
	//PtlParamFont fontDate(PtlParamString("lr SVbN"), fontSizeDate, PtlParamFont::WEIGHT_NORMAL, false, true);
	PtlParamFont fontDate(PtlParamString("Helvetica"), fontSizeDate, PtlParamFont::WEIGHT_NORMAL, false, true);

	// t
	PtlParamString textDate(szDate);

	// t`悷p[^[
	PtlParamWriteString paramWriteStringDate;
	paramWriteStringDate.setFont(fontDate);
	paramWriteStringDate.setTextColor(color);
	paramWriteStringDate.setOutlineColor(color);

	// t`悷`
	PtlRect rectDate(from_x, lower_y, to_x, upper_y);

	// t`
	content.writeString(rectDate, PtlContent::ALIGN_CENTER, textDate, paramWriteStringDate);

	// ÕtHg
	float fontSizeName = sizeStamp / 1.5f;

	// 疼O`悷`܂ł̃}[W
	float margin = sizeStamp / 40.0f;

	// O`̍
	float heightNameBase = upper_y-lower_y;
	float heightName = fontSizeName * 25.4f / 72.0f;
	while (heightName > heightNameBase) {
		fontSizeName -= 0.5f;
		heightName = fontSizeName * 25.4f / 72.0f;
	}

	// ÕtHg
	//PtlParamFont fontName(PtlParamString("lr "), fontSizeName, PtlParamFont::WEIGHT_NORMAL, false, true);
	PtlParamFont fontName(PtlParamString("Helvetica"), fontSizeName, PtlParamFont::WEIGHT_NORMAL, false, true);

	// ̕
	float widthLine = 0.5f;
	// ~̔a
	float rr = r - widthLine;
	// O̍̃WA
	float d = asin((heightName + yy + margin)/rr);
	// O߂`̕
	float widthName = rr * (float)cos(d) * 2;

	// O
	PtlParamString textName(szName);
	float textWidthName = fontName.getStringWidth(textName);

	// O̒ɂtHgTCY̒
	while (textWidthName > widthName) {
		fontSizeName -= 0.5f;
		fontName.setSize(fontSizeName);
		textWidthName = fontName.getStringWidth(textName);
		heightName = fontSizeName * 25.4f / 72.0f;
		d = asin((heightName + yy + margin)/rr);
		widthName = rr * (float)cos(d) * 2;
	}

	// O`悷p[^[
	PtlParamWriteString paramWriteStringName;
	paramWriteStringName.setFont(fontName);
	paramWriteStringName.setTextColor(color);
	paramWriteStringName.setOutlineColor(color);

	// O`悷`
	PtlRect rectName(from_x, lower_y-heightName-margin, to_x, lower_y-margin);

	// O`
	content.writeString(rectName, PtlContent::ALIGN_CENTER, textName, paramWriteStringName);
}
