/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvF摜̑}

	Copyright 2013-2021 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <stdio.h>

using namespace PdfTk;

void appendWatermarkImage(PtlPDFDocument& doc, const char* pathImage);
void appendWatermarkPDF(PtlPDFDocument& doc, const char* pathImage);

int main(int argc, char* argv[])
{
	if (argc < 4) {
		printf("usage: AppendImageWatermark.exe in-pdf-file out-pdf-file watermark-image\n");
		return 1;
	}
	try
	{
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);

		PtlPDFDocument doc;

		// PDFt@C[h܂B
		doc.load(input);

		// ̐ݒ
		appendWatermarkImage(doc, argv[3]);
		//appendWatermarkPDF(doc, argv[3]);

		// t@Cɕۑ܂B
		doc.save(output);

		printf("!\n");
	}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return 1;
	}	
	return 0;
}

void appendWatermarkImage(PtlPDFDocument& doc, const char* pathImage)
{
	// ̐ݒ
	PtlParamWaterMarkImage watermarkimage;

	// ͉摜Xg[̐ݒ
	PtlParamInput inputimage(pathImage);
	watermarkimage.setImageStream(inputimage);
	inputimage.close();

	// ̖O̐ݒ
	watermarkimage.setName("̖O");

	// zuƂ̗]̐ݒ
	watermarkimage.setMargin(10.0f, 10.0f, 10.0f, 10.0f);

	// ̔zu̐ݒ ALIGN_TOP_LEFT = 1 /*  */
	watermarkimage.setAlign(PtlParamWaterMark::ALIGN_TOP_LEFT);

	// ZI[_[̐ݒ ZORDER_FRONT = 1 /* O */
	watermarkimage.setZorder(PtlParamWaterMark::ZORDER_FRONT);

	// y[W͈̔͂̐ݒ PAGE_RANGE_ODD = 3 /* y[W */
	watermarkimage.setPageRange(PtlParamWaterMark::PAGE_RANGE_ODD);

	// ̕sx̐ݒ
	watermarkimage.setOpacity(0.9f);

	// ^COĔzu邩ǂ̐ݒ
	watermarkimage.setTiling(false);

	// ̔{̐ݒ
	watermarkimage.setScale(0.8f);

	// ̐ݒ
	doc.appendWaterMark(watermarkimage);
}

void appendWatermarkPDF(PtlPDFDocument& doc, const char* pathImage)
{
	// ̐ݒ
	PtlParamWaterMarkPDF watermarkpdf;

	// Ɏgp摜y[Wݒ
	PtlParamImagePage imagepage;

	// p^Cv̐ݒ PAPER_IMAGE_SIZE /* 摜TCYɍ킹 */
	imagepage.setPaperType(PtlParamImagePage::PAPER_IMAGE_SIZE);

	// 摜̕`Ɏgp[^NX
	PtlParamDrawImage paramDrawImage;

	// ͉摜Xg[̐ݒ
	PtlParamInput inputimage(pathImage);
	paramDrawImage.setImageStream(inputimage);
	inputimage.close();

	// y[Wɑ}摜p[^̐ݒB
	imagepage.setImage(paramDrawImage);

	PtlPDFDocument doc_img;
	// y[WRei̎擾
	PtlPages& pages = doc_img.getPages();

	// 摜y[W̒ǉ
	pages.append(imagepage);

	// wʒuɂy[W擾
	PtlPage page = pages.get(0);

	// ɎgpPDFy[Wݒ
	watermarkpdf.setPage(page);

	// ̖O̐ݒ
	watermarkpdf.setName("̖O");

	// zuƂ̗]̐ݒ
	watermarkpdf.setMargin(10.0f, 10.0f, 10.0f, 10.0f);

	// ̔zu̐ݒ ALIGN_TOP_LEFT = 1 /*  */
	watermarkpdf.setAlign(PtlParamWaterMark::ALIGN_TOP_LEFT);

	// ZI[_[̐ݒ ZORDER_FRONT = 1 /* O */
	watermarkpdf.setZorder(PtlParamWaterMark::ZORDER_FRONT);

	// y[W͈̔͂̐ݒ PAGE_RANGE_ODD = 3 /* y[W */
	watermarkpdf.setPageRange(PtlParamWaterMark::PAGE_RANGE_ODD);

	// ̕sx̐ݒ
	watermarkpdf.setOpacity(0.9f);

	// ^COĔzu邩ǂ̐ݒ
	watermarkpdf.setTiling(false);

	// ̔{̐ݒ
	watermarkpdf.setScale(0.8f);

	// ̐ݒ
	doc.appendWaterMark(watermarkpdf);
}
