/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvFZLeB̎擾

	Copyright 2013-2021 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <stdio.h>

using namespace PdfTk;

void showEncrypt(PtlPDFDocument& doc);
void showPermissionType1(const PtlEncryptPermission& perms);
void showPermissionType2(const PtlEncryptPermission& perms);
void showPermissionPubKey(const PtlEncryptPermission& perms);

int main(int argc, char* argv[])
{
	if (argc < 2) {
		printf("usage: GetEncryptInfo.exe in-pdf-file [in-pdf-password] [in-pfx]\n");
		return 1;
	}
	try
	{
		PtlParamInput input(argv[1]);

		PtlPDFDocument doc;
		if (argc > 2) {
			PtlParamString password(argv[2]);
			// pX[h̃Zbg
			doc.setPassword(password);
		}
		PtlParamInput pkcs12;
		if (argc > 3) {
			pkcs12 = PtlParamInput(argv[3]);
			// PKCS12Zbg
			doc.setPKCS12(pkcs12);
		}
		// PDFt@C[h܂B
		doc.load(input);

		// Í̎擾
		if (doc.isEncrypted())
		{
			// Í̎擾
			showEncrypt(doc);
		}
		else
		{
		    printf("ÍĂȂt@Cł\n");
		}

		printf("!\n");
}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return 1;
	}	
	return 0;
}

void showEncrypt(PtlPDFDocument& doc)
{
	// Í̎擾
	const PtlEncrypt& encrypt = doc.getEncrypt();	// ÍĂȂƗO

	// L[̎擾
	int keyLength = encrypt.getKeyLength();
	printf("KeyLength : %d\n", keyLength);

	// Í镶R|[lg擾
	PtlEncrypt::ENCRYPT_COMPONENT comp = encrypt.getEncryptComponent();
	switch (comp) {
	case PtlEncrypt::ENCRYPT_ALL:
		printf("̑SẴRecÍ\n");
		break;
	case PtlEncrypt::ENCRYPT_EXCEPT_METADATA:
		printf("̃^f[^SẴRecÍ\n");
		break;
	case PtlEncrypt::ENCRYPT_ONLY_ATTACHED_FILE:
		printf("Ytt@Ĉ݂Í(AESÍ݂̂ŗL)\n");
		break;
	}

	// Í̃tB^[擾
	PtlEncrypt::FILTER_TYPE filterType = encrypt.getFilterType();
	switch (filterType) {
	case PtlEncrypt::FILTER_STANDARD:	// WZLeBnh
		{
			const PtlEncryptStandard& encryptStandard = (const PtlEncryptStandard&)encrypt;

			// WZLeBnh̃\bh擾
			PtlEncryptStandard::STANDARD_METHOD_TYPE method = encryptStandard.getMethod();
			switch (method) {
			case PtlEncryptStandard::METHOD_RC4:
				printf("WZLeBnh : RC4\n");
				break;
			case PtlEncryptStandard::METHOD_AES:
				printf("WZLeBnh : AES\n");
				break;
			}
			// [UANZXtO̎擾
			const PtlEncryptPermission& perms = encryptStandard.getPermission();

			switch (perms.getType()) {
			case PtlEncryptPermission::PERM_TYPE1:
				printf("\nWZLeBnh RC4 40 rbg Íł̌\n");
				showPermissionType1(perms);
				break;
			case PtlEncryptPermission::PERM_TYPE2:
				printf("\nWZLeBnh RC4 40 rbgȊÖÍł̌\n");
				showPermissionType2(perms);
				break;
			}
		}
		break;
	case PtlEncrypt::FILTER_PUBKEY:	// JL[ZLeBnh
		{
			const PtlEncryptPubKey& encryptPubKey = (const PtlEncryptPubKey&)encrypt;

			// JL[ZLeBnh̃\bh擾
			PtlEncryptPubKey::PUBSEC_METHOD_TYPE method = encryptPubKey.getMethod();
			switch (method) {
			case PtlEncryptStandard::METHOD_RC4:
				printf("JL[ZLeBnh : RC4\n");
				break;
			case PtlEncryptStandard::METHOD_AES:
				printf("JL[ZLeBnh : AES\n");
				break;
			}

			// [UANZXtO̎擾
			const PtlEncryptPermission& perms = encryptPubKey.getPermission();

			printf("\nJL[ZLeBnȟ\n");
			showPermissionPubKey(perms);
		}
		break;
	}
}

void showPermissionType1(const PtlEncryptPermission& perms)
{
	const PtlEncryptPermissionType1& perms1 = (const PtlEncryptPermissionType1&)perms;
	// 擾
	bool print = perms1.getPrint();
	if (print){
		printf("\n");
	}else{
		printf("Ȃ\n");
	}
	// ύX擾
	PtlEncryptPermissionType1::PERMISSION_MODIFY modify  = perms1.getModify();
	switch (modify) {
	case PtlEncryptPermissionType1::PERM_MODIFY_NOT_ALLOWED:
		printf("ύX : Ȃ\n");
		break;
	case PtlEncryptPermissionType1::PERM_MODIFY_ANNOTANDFORM:
		printf("ύX : ߂̍쐬AtH[tB[h̓͂Ɗ̏tB[hɏ\n");
		break;
	case PtlEncryptPermissionType1::PERM_MODIFY_ASSEMBLEANDFORM:
		printf("ύX : y[WCAEgAtH[tB[h̓͂Ɗ̏tB[hɏ\n");
		break;
	case PtlEncryptPermissionType1::PERM_MODIFY_MODYFYDOC:
		printf("ύX : y[WoSĂ̓\n");
		break;
	}
	// eLXgA摜Ȃ̓ẽRs[уANZVreBLɂ邩ǂ̎擾
	bool copy = perms1.getCopy();
	if (copy){
		printf("eLXgA摜Ȃ̓ẽRs[уANZVreBLɂ\n");
	}else{
		printf("eLXgA摜Ȃ̓ẽRs[уANZVreBLɂȂ\n");
	}
}

void showPermissionType2(const PtlEncryptPermission& perms)
{
	const PtlEncryptPermissionType2& perms2 = (const PtlEncryptPermissionType2&)perms;
	// 擾
	PtlEncryptPermissionType2::PERMISSION_PRINT print = perms2.getPrint();
	switch (print) {
	case PtlEncryptPermissionType2::PERM_PRINT_NOT_ALLOWED:
		printf(" : Ȃ\n");
		break;
	case PtlEncryptPermissionType2::PERM_PRINT_LOW:
		printf(" : 𑜓x\n");
		break;
	case PtlEncryptPermissionType2::PERM_PRINT_HIGH:
		printf(" : 𑜓x\n");
		break;
	}
	// ύX擾
	PtlEncryptPermissionType2::PERMISSION_MODIFY modify  = perms2.getModify();
	switch (modify) {
	case PtlEncryptPermissionType2::PERM_MODIFY_NOT_ALLOWED:
		printf("ύX : Ȃ\n");
		break;
	case PtlEncryptPermissionType2::PERM_MODIFY_ASSEMBLEDOC:
		printf("ύX : y[W̑}A폜A]\n");
		break;
	case PtlEncryptPermissionType2::PERM_MODIFY_FILLFORM:
		printf("ύX : tH[tB[h̓͂Ɗ̏tB[hɏ\n");
		break;
	case PtlEncryptPermissionType2::PERM_MODIFY_ANNOTANDFORM:
		printf("ύX : ߂̍쐬AtH[tB[h̓͂Ɗ̏tB[hɏ\n");
		break;
	case PtlEncryptPermissionType2::PERM_MODIFY_MODYFYDOC:
		printf("ύX : y[WoSĂ̓\n");
		break;
	}
	// eLXgA摜Ȃ̓ẽRs[Lɂ邩ǂ̎擾
	bool copy = perms2.getCopy();
	if (copy){
		printf("eLXgA摜Ȃ̓ẽRs[Lɂ\n");
	}else{
		printf("eLXgA摜Ȃ̓ẽRs[LɂȂ\n");
	}
	// XN[[_[foCX̃eLXgANZXLɂ邩ǂ̎擾
	bool acc = perms2.getAccessibility();
	if (acc){
		printf("XN[[_[foCX̃eLXgANZXLɂ\n");
	}else{
		printf("XN[[_[foCX̃eLXgANZXLɂȂ\n");
	}
}

void showPermissionPubKey(const PtlEncryptPermission& perms)
{
	const PtlEncryptPermissionPubKey& permsPubKey = (const PtlEncryptPermissionPubKey&)perms;
	bool fullPermission = permsPubKey.hasFullPermission();
	if (fullPermission){
		printf("SĂ̌\n");
		printf("ȉ͖̌\n\n");
	}else{
		printf("SĂ̌ł͂Ȃ\n");
		printf("ȉ̌ɏ]\n\n");
	}

	showPermissionType2(perms);
}
