﻿/*
	Antenna House PDF Tool API V6.0
	.NET Interface sample program

	概要：テキストエレメント取得

	Copyright 2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace ExtractTextElem
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 1)
            {
                Console.WriteLine("usage: ExtractTextElem.exe in-pdf-file\n");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0])) 
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    using (PtlPages pages = doc.getPages())
                    {
                        //ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空");
                            return;
                        }

                        using (PtlPage page = pages.get(0)) // 先頭ページ
                        {
                            // テキスト抽出
                            extractText(page);
                        }
                    }
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

        static void extractText(PtlPage page)
        {
            using (PtlContent content = page.getContent()) // ページコンテントの取得
            using (PtlEditElements elems = content.getEditElements(PtlContent.GET_ELEMENT.GET_TEXT)) // テキストエレメントの取得
            {
                int numElems = elems.getCount();
                for (int i = 0; i < numElems; ++i)
                {
                	// テキストエレメントの取得
                    using (PtlEditElement elem = elems.get(i))
                    {
				        PtlEditText elemText = (PtlEditText)elem;
                        // テキストアイテムの取得
                        using (PtlEditTextItems elemTextItems = elemText.getTextItems())
                        {
                            int numItems = elemTextItems.getCount();
                            for (int j = 0; j < numItems; ++j)
                            {
                                using (PtlEditTextItem textItem = elemTextItems.get(j))
                                {
                                    // テキスト
                                    String text = textItem.getText();
                                    // テキストを囲む矩形
                                    using (PtlRect bbox = textItem.getBBox())
                                    {
                                        float left = bbox.getLeft();
                                        float top = bbox.getTop();
                                        float right = bbox.getRight();
                                        float bottom = bbox.getBottom();
                                    }
                                    // テキストを囲む4点の座標
                                    using (PtlQuadPoint quadPoint = textItem.getQuadPoint())
                                    {
                                        using (PtlPoint bottomLeft = quadPoint.getBottomLeft())
                                        {
                                            float bl_x = bottomLeft.getX();
                                            float bl_y = bottomLeft.getY();
                                        }
                                        using (PtlPoint topLeft = quadPoint.getTopLeft())
                                        {
                                            float tl_x = topLeft.getX();
                                            float tl_y = topLeft.getY();
                                        }
                                        using (PtlPoint topRight = quadPoint.getTopRight())
                                        {
                                            float tr_x = topRight.getX();
                                            float tr_y = topRight.getY();
                                        }
                                        using (PtlPoint bottomRight = quadPoint.getBottomRight())
                                        {
                                            float br_x = bottomRight.getX();
                                            float br_y = bottomRight.getY();
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}
