﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：注釈情報の取得／注釈の削除

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace GetAnnots
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 3)
            {
                Console.WriteLine("usage: GetAnnots.exe in-pdf-file out-pdf-file 削除方法\n");
                Console.WriteLine("削除方法\n0 : ひとつめの注釈の削除 1 : 全注釈の削除\n");
                return;
            }
            String kind = args[2];
            switch (kind)
            {
                case "0":
                case "1":
                    break;
                default:
                    Console.WriteLine("usage: GetAnnots.exe in-pdf-file out-pdf-file 削除方法\n");
                    Console.WriteLine("削除方法\n0 : ひとつめの注釈の削除 1 : 全注釈の削除\n");
                    return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // ページコンテナの取得
                    using (PtlPages pages = doc.getPages())
                    {
                        // ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空");
                            return;
                        }

                        // 1ページ目の取得
                        using (PtlPage page = pages.get(0))
                        {
                            // 注釈コンテナの取得
                            using (PtlAnnots annots = page.getAnnots())
                            {
                                // 注釈コンテナが空かどうか
                                if (annots.isEmpty())
                                {
                                    Console.WriteLine("注釈空");
                                }
                                else
                                {
                                    //注釈数の取得
                                    Console.WriteLine("注釈数 : " + annots.getCount());

                                    switch (kind)
                                    {
                                    case "0":
                                        // 注釈の削除
                                        annots.remove(0);
                                        break;
                                    case "1":
                                        // 全注釈の削除
                                        annots.removeAll();
                                        break;
                                    }
                                }
                            }
                        }
                    }
                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
