﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：Separation Color

	Copyright 2021 Antenna House,Inc.
*/

using System;
using PdfTkNet;

namespace SeparationColor
{
    class SeparationColor
    {
        static void Main(string[] args)
        {
            if (args.Length < 2)
            {
                Console.WriteLine("usage: SeparationColor.exe in-pdf-file out-pdf-file");
                return;
            }
            try
            {
                using (PtlParamInput input = new PtlParamInput(args[0]))
                using (PtlParamOutput output = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    string separationName = "colorName";

                    float c = 0.0f;             //シアンの値。0.0から1.0までの値
                    float m = 1.0f;             //マゼンタの値。0.0から1.0までの値
                    float y = 1.0f;             //黄の値。0.0から1.0までの値
                    float k = 0.0f;             //黒の値。0.0から1.0までの値
                    float sepValue = 0.5f;      //0.0 ～ 1.0までの値

                    // PDFファイルをロードします。
                    doc.load(input);

                    using (PtlPages pages = doc.getPages())
                    using (PtlParamDrawShape shape = new PtlParamDrawShape())
                    using (PtlColorSpaceSeparation cs = new PtlColorSpaceSeparation(separationName, c, m, y, k))
                    using (PtlColorSeparation color = new PtlColorSeparation(cs, sepValue))
                    {
                        int pageCnt = doc.getPageCount();
                        shape.setFillColor(color);
                        shape.setLineColor(color);

                        using (PtlPage page = pages.get(0))
                        using (PtlContent content = page.getContent())
                        using (PtlRect rect = new PtlRect(0.0f, 0.0f, 100.0f, 100.0f))  // Circle
                        {
                            //円形を描画
                            content.drawCircle(rect, shape);
                        }
                        doc.save(output);
                    }
                }
                Console.WriteLine("完了!");
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
        }
    }
}
