/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：ファイルの添付

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class AppendEmbeddedFile {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java AppendEmbeddedFile in-pdf-file out-pdf-file embedded-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            String embeddedfilename = args[2];

            // PDFファイルをロード
            doc.load(inputFile);
            
            // 添付ファイルコンテナの取得
            try (PtlEmbeddedFiles embeddedfiles = doc.getEmbeddedFiles())
            {
                // 添付ファイル数の取得
                System.out.println("追加前の添付ファイル数 : " + embeddedfiles.getCount());

                // PDFの添付ファイル
                try (PtlEmbeddedFile embeddedfile = new PtlEmbeddedFile();
                     PtlParamInput inputEmbed = new PtlParamInput(embeddedfilename))
                {
                    // 添付ファイル名の設定
                    embeddedfile.setFileName(embeddedfilename);

                    // 添付するファイルの読み込み
                    embeddedfile.readFile(inputEmbed);

                    // 添付ファイルの追加
                    embeddedfiles.append(embeddedfile);

                    // 添付ファイル数の取得
                    System.out.println("追加後の添付ファイル数 : " + embeddedfiles.getCount());

                }
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
