/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：証明書セキュリティの設定

    Copyright 2021 Antenna House, Inc.
*/

package Sample;

import java.io.*;
import jp.co.antenna.ptl.*;

public class EncryptPubSec {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 5)
        {
            System.out.println("usage: java Encrypt in-pdf-file out-pdf-file 暗号化種類 証明書種類 証明書file [証明書パスワード(pfx)]\n");
            System.out.println("暗号化種類\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
            return;
        }

        switch (args[2]) {
        case "0":
        case "1":
        case "2":
            break;
        default:
            System.out.println("usage: java Encrypt in-pdf-file out-pdf-file 暗号化種類 証明書種類 証明書file [証明書パスワード(pfx)]\n");
            System.out.println("暗号化種類\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
            return;
        }

        switch (args[3]) {
        case "1":
            break;
        case "0":
            if (args.length > 4) {
				break;
			}
        default:
            System.out.println("usage: java Encrypt in-pdf-file out-pdf-file 暗号化種類 証明書種類 証明書file [証明書パスワード(pfx)]\n");
            System.out.println("暗号化種類\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);

            try (PtlParamInput inputCert = new PtlParamInput(args[4]))
            {
	            // セキュリティ設定
	            switch (args[2])
	            {
	            case "0":
	                // 128 bit RC4
	                try (PtlEncryptPubKey128RC4 enc = new PtlEncryptPubKey128RC4())
	                {
	                    switch (args[3])
	                    {
	                    case "0":
	                        encryptPubKeyPKCS12(enc, inputCert, args[5]);
	                        break;
	                    case "1":
	                        encryptPubKeyX509(enc, inputCert);
	                        break;
	                    }
	                    doc.setEncrypt(enc);
	                }
	                break;
	            case "1":
	                // 128 bit AES
	                try (PtlEncryptPubKey128AES enc = new PtlEncryptPubKey128AES())
	                {
	                    switch (args[3])
	                    {
	                    case "0":
	                        encryptPubKeyPKCS12(enc, inputCert, args[5]);
	                        break;
	                    case "1":
	                        encryptPubKeyX509(enc, inputCert);
	                        break;
	                    }
	                    doc.setEncrypt(enc);
	                }
	                break;
	            case "2":
	                // 256 bit AES
	                try (PtlEncryptPubKey256AES enc = new PtlEncryptPubKey256AES())
	                {
	                    switch (args[3])
	                    {
	                    case "0":
	                        encryptPubKeyPKCS12(enc, inputCert, args[5]);
	                        break;
	                    case "1":
	                        encryptPubKeyX509(enc, inputCert);
	                        break;
	                    }
	                    doc.setEncrypt(enc);
	                }
	                break;
	            }
	        }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
    
    public static void encryptPubKeyPKCS12(PtlEncryptPubKey enc, PtlParamInput inputPfx, String password) throws PtlException, Exception, Error
    {
        // 文書の全てのコンテンツを暗号化
        enc.setEncryptComponent(PtlEncrypt.ENCRYPT_COMPONENT.ENCRYPT_ALL);

        try (PtlRecipients recipients = enc.getRecipients();
             PtlRecipient recipient = new PtlRecipient())
        {
            recipient.setPKCS12(inputPfx, password);
            // 権限設定
            setPubKey(recipient);

            recipients.append(recipient);
        }
    }

    public static void encryptPubKeyX509(PtlEncryptPubKey enc, PtlParamInput inputCer) throws PtlException, Exception, Error
    {
        // 文書の全てのコンテンツを暗号化
        enc.setEncryptComponent(PtlEncrypt.ENCRYPT_COMPONENT.ENCRYPT_ALL);

        try (PtlRecipients recipients = enc.getRecipients();
             PtlRecipient recipient = new PtlRecipient())
        {
            recipient.setX509(inputCer);
            // 権限設定
            setPubKey(recipient);

            recipients.append(recipient);
        }
    }

    public static void setPubKey(PtlRecipient recipient) throws PtlException, Exception, Error
    {
        try (PtlEncryptPermissionPubKey typ = new PtlEncryptPermissionPubKey())
        {
            // 印刷権限の設定
            // PERM_PRINT_LOW = 1, /* 低解像度 */
            typ.setPrint(PtlEncryptPermissionType2.PERMISSION_PRINT.PERM_PRINT_LOW);

            // 変更権限の設定
            // PERM_MODIFY_ASSEMBLEDOC = 1, /* ページの挿入、削除、回転 */
            typ.setModify(PtlEncryptPermissionType2.PERMISSION_MODIFY.PERM_MODIFY_ASSEMBLEDOC);

            // テキスト、画像、その他の内容のコピーを有効にするかどうかの設定
            // false: 有効にしない
            typ.setCopy(false);

            // スクリーンリーダーデバイスのテキストアクセスを有効にするかどうかの設定
            // true: 有効にする
            typ.setAccessibility(true);

            // ユーザアクセス許可フラグの設定
            recipient.setPermission(typ);
        }
    }
}

