/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：画像抽出

    Copyright 2018-2021 Antenna House, Inc.
*/

package Sample;

import java.io.*;
import jp.co.antenna.ptl.*;

public class ExtractImage {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java ExtractImage in-pdf-file out-image-file 出力フォーマット\n");
            System.out.println("出力フォーマット\n0 : 自動  1 : BMP  2 : JPEG  3 : PNG\n");
            return;
        }

        String kind = args[2];
        switch (kind) {
        case "0":
        case "1":
        case "2":
        case "3":
            break;
        default:
            System.out.println("usage: java ExtractImage in-pdf-file out-image-file 出力フォーマット\n");
            System.out.println("出力フォーマット\n0 : 自動  1 : BMP  2 : JPEG  3 : PNG\n");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);

            try (PtlPages pages = doc.getPages()) // ページコンテナの取得
            {
                // ページコンテナが空かどうか
                if (pages.isEmpty())
                {
                    System.out.println("ページコンテナが空");
                    return;
                }

                // １ページ目の取得
                try (PtlPage page = pages.get(0))
                {
                    // 画像抽出
                    extractImage(page, args[1], kind);
                }
            }
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }

    public static void extractImage(PtlPage page, String imagefilename, String kind) throws PtlException, Exception, Error
    {
        int numImage = 0;
        try (PtlContent content = page.getContent(); // ページコンテントの取得
             PtlEditElements elems = content.getEditElements(PtlContent.GET_IMAGE)) // 画像エレメントの取得
        {
            int numElems = elems.getCount();
            if (numElems == 0) return;

            PtlEditImage.OUTPUT_FORMAT format = PtlEditImage.OUTPUT_FORMAT.FORMAT_AUTO;
            switch (kind) {
            case "1":
                format = PtlEditImage.OUTPUT_FORMAT.FORMAT_BMP;
                break;
            case "2":
                format = PtlEditImage.OUTPUT_FORMAT.FORMAT_JPEG;
                break;
            case "3":
                format = PtlEditImage.OUTPUT_FORMAT.FORMAT_PNG;
                break;
            }

            for (int i = 0; i < numElems; ++i)
            {
                // 画像エレメントの取得
                try (PtlEditElement elem = elems.get(i))
                {
                    PtlEditElement.ELEMENT_TYPE type = elem.getType();
                    switch (type)
                    {
                        case TYPE_IMAGE:
                            {
                                ++numImage;
                                PtlEditImage elemImage = (PtlEditImage)elem;
                                String pathImage = "";
                                switch (format)
                                {
                                    case FORMAT_AUTO:
                                        pathImage = String.format("%s%d", imagefilename, numImage);
                                        break;
                                    case FORMAT_BMP:
                                        pathImage = String.format("%s%d.bmp", imagefilename, numImage);
                                        break;
                                    case FORMAT_JPEG:
                                        pathImage = String.format("%s%d.jpg", imagefilename, numImage);
                                        break;
                                    case FORMAT_PNG:
                                        pathImage = String.format("%s%d.png", imagefilename, numImage);
                                        break;
                                }
                                try (PtlParamOutput outputImage = new PtlParamOutput(pathImage))
                                {
                                    // 画像出力
                                    elemImage.writeFile(outputImage, format);
                                }
                            }
                            break;
                        default:
                            break;
                    }
                }
            }
        }
    }
}
