/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：テキストエレメント取得

    Copyright 2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class ExtractTextElem {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 1)
        {
            System.out.println("usage: java ExtractTextElem in-pdf-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);

            try (PtlPages pages = doc.getPages()) // ページコンテナの取得
            {
                // ページコンテナが空かどうか
                if (pages.isEmpty())
                {
                    System.out.println("ページコンテナが空");
                    return;
                }

                // １ページ目の取得
                try (PtlPage page = pages.get(0))
                {
                     // テキスト抽出
                    extractText(page);
                }
            }
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }

    public static void extractText(PtlPage page) throws PtlException, Exception, Error
    {
        try (PtlContent content = page.getContent(); // ページコンテントの取得
             PtlEditElements elems = content.getEditElements(PtlContent.GET_TEXT)) // テキストエレメントの取得
        {
            int numElems = elems.getCount();
            for (int i = 0; i < numElems; ++i)
            {
                // テキストエレメントの取得
                try (PtlEditElement elem = elems.get(i))
                {
                    PtlEditText elemText = (PtlEditText)elem;
                    // テキストアイテムの取得
                    try (PtlEditTextItems elemTextItems = elemText.getTextItems())
                    {
                        int numItems = elemTextItems.getCount();
                        for (int j = 0; j < numItems; ++j)
                        {
                            try (PtlEditTextItem textItem = elemTextItems.get(j))
                            {
                                // テキスト
                                String text = textItem.getText();
                                System.out.println(text);
                                // テキストを囲む矩形
                                try (PtlRect bbox = textItem.getBBox())
                                {
                                    float left = bbox.getLeft();
                                    float top = bbox.getTop();
                                    float right = bbox.getRight();
                                    float bottom = bbox.getBottom();
                                }
                                // テキストを囲む4点の座標
                                try (PtlQuadPoint quadPoint = textItem.getQuadPoint())
                                {
                                    try (PtlPoint bottomLeft = quadPoint.getBottomLeft())
                                    {
                                        float bl_x = bottomLeft.getX();
                                        float bl_y = bottomLeft.getY();
                                    }
                                    try (PtlPoint topLeft = quadPoint.getTopLeft())
                                    {
                                        float tl_x = topLeft.getX();
                                        float tl_y = topLeft.getY();
                                    }
                                    try (PtlPoint topRight = quadPoint.getTopRight())
                                    {
                                        float tr_x = topRight.getX();
                                        float tr_y = topRight.getY();
                                    }
                                    try (PtlPoint bottomRight = quadPoint.getBottomRight())
                                    {
                                        float br_x = bottomRight.getX();
                                        float br_y = bottomRight.getY();
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}
