/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：開き方の取得

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class GetOpenMode {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 1)
        {
            System.out.println("usage: java GetOpenMode in-pdf-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロード
            doc.load(inputFile);

            try (PtlDocProperty docProperty = doc.getDocProperty();  //PDFの文書プロパティ
                 PtlOpenMode openmode = docProperty.getOpenMode()) { //開き方の取得

                // ページモードの取得
                switch (openmode.getPageMode())
                {
                case PAGE_MODE_USE_NONE:
                    System.out.println("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_NONE + " : ページのみ表示");
                    break;
                case PAGE_MODE_USE_OUTLINES:
                    System.out.println("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_OUTLINES + " : しおりパネルとページ");
                    break;
                case PAGE_MODE_USE_THUMBS:
                    System.out.println("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_THUMBS + " : サムネイルパネルとページ");
                    break;
                case PAGE_MODE_USE_OC:
                    System.out.println("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_OC + " : レイヤーパネルとページ");
                    break;
                case PAGE_MODE_USE_ATTACHMENTS:
                    System.out.println("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_ATTACHMENTS + " : 添付ファイルパネルとページ");
                    break;
                }

                // ページレイアウトの取得
                switch (openmode.getPageLayout())
                {
                case PAGE_LAYOUT_SINGLE_PAGE:
                    System.out.println("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_SINGLE_PAGE + " : 単一ページ");
                    break;
                case PAGE_LAYOUT_ONE_COLUMN:
                    System.out.println("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_ONE_COLUMN + " : 連続ページ");
                    break;
                case PAGE_LAYOUT_TWO_COLUMN_LEFT:
                    System.out.println("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_COLUMN_LEFT + " : 奇数ページを左側にして連続見開きページ");
                    break;
                case PAGE_LAYOUT_TWO_COLUMN_RIGHT:
                    System.out.println("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_COLUMN_RIGHT + " : 奇数ページを右側にして連続見開きページ");
                    break;
                case PAGE_LAYOUT_TWO_PAGE_LEFT:
                    System.out.println("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_PAGE_LEFT + " : 奇数ページを左側にして見開きページ");
                    break;
                case PAGE_LAYOUT_TWO_PAGE_RIGHT:
                    System.out.println("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_PAGE_RIGHT + " : 奇数ページを右側にして見開きページ");
                    break;
                }

                // オープンアクションの取得
                try (PtlAction action = openmode.getOpenAction())
                {
                    showAction(action);
                }

                // 宛先ページの取得(ページ番号は0ベース)
                // この宛先はdoc内の宛先になります。他PDFの宛先はPtlActionGoToRのgetDestで取得します。
                try (PtlDest dest = openmode.getOpenDest())
                {
                    showDest(dest);
                }

                // ウインドウオプションを取得（論理和） 
                if (openmode.getWindowOption() == PtlOpenMode.WINDOWS_OPTION_NONE)
                {
                    System.out.println("WindowOption : " + PtlOpenMode.WINDOWS_OPTION_NONE + " : なし");
                }
                if ((openmode.getWindowOption() & PtlOpenMode.WINDOWS_OPTION_FIT_WINDOW) == PtlOpenMode.WINDOWS_OPTION_FIT_WINDOW)
                {
                    System.out.println("WindowOption : " + PtlOpenMode.WINDOWS_OPTION_FIT_WINDOW + " : ページにウィンドウサイズを合わせる");
                }
                if ((openmode.getWindowOption() & PtlOpenMode.WINDOWS_OPTION_CENTER_WINDOW) == PtlOpenMode.WINDOWS_OPTION_CENTER_WINDOW)
                {
                    System.out.println("WindowOption : " + PtlOpenMode.WINDOWS_OPTION_CENTER_WINDOW + " : ウィンドウを画面中央に配置");
                }
                if ((openmode.getWindowOption() & PtlOpenMode.WINDOWS_OPTION_FULL_SCREEN) == PtlOpenMode.WINDOWS_OPTION_FULL_SCREEN)
                {
                    System.out.println("WindowOption : " + PtlOpenMode.WINDOWS_OPTION_FULL_SCREEN + " : フルスクリーンモードで開く");
                }

                // ウィンドウのタイトルバーに文書タイトルを表示するかどうか取得（true: 非表示、false: 表示）
                if (openmode.getDisplayDocTitle())
                {
                    System.out.println("DisplayDocTitle : 非表示");
                }
                else
                {
                    System.out.println("DisplayDocTitle : 表示");
                }

                // ユーザーインターフェイスオプションを取得（論理和）
                if (openmode.getUIOption() == PtlOpenMode.UI_OPTION_NONE)
                {
                    System.out.println("UIOption : " + PtlOpenMode.UI_OPTION_NONE + " : なし");
                }
                if ((openmode.getUIOption() & PtlOpenMode.UI_OPTION_HIDE_MENUBAR) == PtlOpenMode.UI_OPTION_HIDE_MENUBAR)
                {
                    System.out.println("UIOption : " + PtlOpenMode.UI_OPTION_HIDE_MENUBAR + " : メニューバーを非表示");
                }
                if ((openmode.getUIOption() & PtlOpenMode.UI_OPTION_HIDE_TOOLBAR) == PtlOpenMode.UI_OPTION_HIDE_TOOLBAR)
                {
                    System.out.println("UIOption : " + PtlOpenMode.UI_OPTION_HIDE_TOOLBAR + " : ツールバーを非表示");
                }
                if ((openmode.getUIOption() & PtlOpenMode.UI_OPTION_HIDE_WINDOWUI) == PtlOpenMode.UI_OPTION_HIDE_WINDOWUI)
                {
                    System.out.println("UIOption : " + PtlOpenMode.UI_OPTION_HIDE_WINDOWUI + " : ウインドウコントロールを非表示");
                }

                // 読み上げオプション取得
                PtlDocProperty.DIRECTION direction = docProperty.getDirection();
                switch (direction) {
                case DIRECTION_L2R:
                    System.out.println("DIRECTION = L2R(左から右)" );
                    break;
                case DIRECTION_R2L:
                    System.out.println("DIRECTION = R2L(右から左(中国語、日本語、韓国語のような縦書きも含む))" );
                    break;
                }
            }
        }
        catch(PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch(Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }

    public static void showAction(PtlAction action) throws PtlException, Exception, Error
    {
        switch (action.getType())
        {
        case TYPE_NONE:
            {
                System.out.println("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_NONE + " : アクションなし");
                break;
            }
        case TYPE_GOTO:
            {
                System.out.println("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_GOTO + " : GoToアクション");
                PtlActionGoTo act = (PtlActionGoTo)action;
                // 宛先の取得
                try (PtlDest dest = act.getDest())
                {
                    showDest(dest);
                }
                break;
            }
        case TYPE_GOTO_R:
            {
                System.out.println("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_GOTO_R + " : GoToRアクション");
                PtlActionGoToR act = (PtlActionGoToR)action;
                // ファイル間移動用PDFファイル名を取得 getFileName()
                System.out.println("FileName : " + act.getFileName());
                // 新ウィンドウフラグを取得
                if (act.getNewWindowFlag())
                {
                    System.out.println("NewWindowFlag : true: 新ウィンドウでオープンする");
                }
                else
                {
                    System.out.println("NewWindowFlag : false: しない");
                }
                // 宛先の取得
                try (PtlDest dest = act.getDest())
                {
                    showDest(dest);
                }
                break;
            }
        case TYPE_LAUNCH:
            {
                System.out.println("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_LAUNCH + " : Launchアクション");
                PtlActionLaunch act = (PtlActionLaunch)action;
                // 起動ファイル名を取得
                System.out.println("FileName : " + act.getFileName());
                // 新ウィンドウフラグを取得
                if (act.getNewWindowFlag())
                {
                    System.out.println("NewWindowFlag : true: 新ウィンドウでオープンする");
                }
                else
                {
                    System.out.println("NewWindowFlag : false: しない");
                }
                break;
            }
        case TYPE_URI:
            {
                System.out.println("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_URI + " : URIアクション");
                PtlActionURI act = (PtlActionURI)action;
                // URIを取得
                System.out.println("URI : " + act.getURI());
                break;
            }
        case TYPE_UNKNOWN:
            {
                System.out.println("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_UNKNOWN + " : 未対応アクション");
                break;
            }
        }
    }

    public static void showDest(PtlDest dest) throws PtlException, Exception, Error
    {
        switch (dest.getType())
        {
        case TYPE_NONE:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_NONE + " : 宛先なし");
            break;
        case TYPE_XYZ:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_XYZ + " : XYZ型");
            break;
        case TYPE_FIT:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT + " : Fit型(全体表示)");
            break;
        case TYPE_FIT_H:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_H + " : FitH型(幅に合わせる)");
            break;
        case TYPE_FIT_V:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_V + " : FitV型(高さに合わせる)");
            break;
        case TYPE_FIT_R:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_R + " : FitR型");
            break;
        case TYPE_FIT_B:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_B + " : FitB型");
            break;
        case TYPE_FIT_BH:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_BH + " : FitBH型(描画領域の幅に合わせる)");
            break;
        case TYPE_FIT_BV:
            System.out.println("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_BV + " : FitBV型");
            break;
        }
        // 宛先ページの取得
        System.out.println("宛先ページ(PageNumber) : " + (dest.getPageNumber()) + " ページ目");
    }
}
