/*
	Antenna House PDF Tool API V7.0
	Java Interface sample program

	概要：フォームデータのXFDFからのインポート

	Copyright 2021 Antenna House,Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class ImportFormDataXFDF {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java ImportFormDataXFDF in-pdf-file out-xfdf-file in-xfdf-file");
            return;
        }
        try (PtlParamInput input = new PtlParamInput(args[0]);
             PtlParamOutput output = new PtlParamOutput(args[1]);
             PtlParamInput inputXFDF = new PtlParamInput(args[2]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(input);

            doc.importFormFieldsFromXFDF(inputXFDF);    //フォームフィールドデータのXFDF文書からのインポート

            doc.save(output);
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
