/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：添付ファイルの書き出し

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import java.io.*;
import jp.co.antenna.ptl.*;

public class OutputEmbeddedFile {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 2)
        {
            System.out.println("usage: java OutputEmbeddedFile in-pdf-file write-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlPDFDocument doc = new PtlPDFDocument();
             PtlParamOutput writeFile = new PtlParamOutput(args[1]))
        {
            // PDFファイルをロード
            doc.load(inputFile);

            // 添付ファイルコンテナが空かどうか
            if (!doc.hasEmbeddedFiles())
            {
                System.out.println("添付ファイルコンテナは空");
                return;
            }

            // 添付ファイルコンテナの取得
            try (PtlEmbeddedFiles embeddedfiles = doc.getEmbeddedFiles())
            {
                // 添付ファイル数の取得
                System.out.println("添付ファイル数 : " + embeddedfiles.getCount());

                // １番目の添付ファイルの取得
                try (PtlEmbeddedFile embeddedfile = embeddedfiles.get(0))
                {
                    System.out.println("１番目の添付ファイル名 : " + embeddedfile.getFileName());

                    // 添付ファイルの書き出し
                    System.out.println("１番目の添付ファイルの書き出し...");
                    embeddedfile.writeFile(writeFile);
                }
            }
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
